This [EXPERIMENTAL] function combines several sampling tricks to compute a version of an importance sample (based on flat priors) for the parameters.
pop_pred_samp(
object,
n = 1000,
n_imp = n * 10,
return_wts = FALSE,
impsamp = FALSE,
PDify = FALSE,
PDmethod = NULL,
Sigma = vcov(object),
tol = 1e-06,
return_all = FALSE,
rmvnorm_method = c("mvtnorm", "MASS"),
fix_params = NULL,
...
)a fitted mle2 object
number of samples to return
number of total samples from which to draw, if doing importance sampling
return a column giving the weights of the samples, for use in weighted summaries?
subsample values (with replacement) based on their weights?
use Gill and King generalized-inverse procedure to correct non-positive-definite variance-covariance matrix if necessary?
method for fixing non-positive-definite covariance matrices
covariance matrix for sampling
tolerance for detecting small eigenvalues
return a matrix including all values, and weights (rather than taking a sample)
package to use for generating MVN samples
parameters to fix (in addition to parameters that were fixed during estimation)
additional parameters to pass to the negative log-likelihood function
Gill, Jeff, and Gary King. "What to Do When Your Hessian Is Not Invertible: Alternatives to Model Respecification in Nonlinear Estimation." Sociological Methods & Research 33, no. 1 (2004): 54-87. Lande, Russ and Steinar Engen and Bernt-Erik Saether, Stochastic Population Dynamics in Ecology and Conservation. Oxford University Press, 2003.