Learn R Programming

bbmle (version 0.8.9)

profile-methods: Likelihood profiles

Description

Methods for creating and plotting likelihood profiles

Usage

## S3 method for class 'mle2':
profile(fitted, which = 1:p, maxsteps = 100,
                    alpha = 0.01, zmax = sqrt(qchisq(1 - alpha/2, p)),
                    del = zmax/5, trace = FALSE, skiperrs=TRUE,
                    tol.newmin = 0.001, ...)
fitted{A fitted maximum likelihood model of class
mle2}
  which{a numeric or character vector describing which parameters
to profile (default is to profile all parameters)}
  maxsteps{maximum number of steps to take looking for an upper
value of the negative log-likelihood}
  alpha{maximum confidence level}
  zmax{maximum value of negative log-likelihood (default
  is the likelihood ratio test critical value corresponding to a
  2-tailed chi-squared test at level alpha)}
  del{step size for profiling}
  trace{(logical) produce tracing output?}
  skiperrs{(logical) ignore errors produced during profiling?}
  tol.newmin{tolerance for finding a new minimum below the
    minimum negative log-likelihood estimated in initial fit}
  ...{not used}
(Describe profiling process further.)
methods

Arguments